# -*- coding: utf-8 -*-
from hurry.workflow.interfaces import IWorkflowState
from zope.component import getUtility
from waeup.kofa.testing import FunctionalTestCase
from waeup.kofa.university.faculty import Faculty
from waeup.kofa.university.department import Department
from waeup.kofa.students.interfaces import IStudentsUtils
from waeup.kofa.students.tests.test_browser import StudentsFullSetup
from waeup.kwarapoly.testing import FunctionalLayer

class StudentsUtilsTests(StudentsFullSetup):

    layer = FunctionalLayer

    def test_getAccommodationDetails(self):
        students_utils = getUtility(IStudentsUtils)
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_fr')

        self.student['studycourse'].current_level = 200
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_re')

        self.student['studycourse'].current_level = 210
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_re')

        self.student['studycourse'].current_level = 300
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_fi')

        self.student['studycourse'].current_level = 400
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_fr')

        self.student['studycourse'].current_level = 500
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_re')

        self.student['studycourse'].current_level = 510
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_re')

        self.student['studycourse'].current_level = 600
        acc_details  = students_utils.getAccommodationDetails(self.student)
        self.assertEqual(acc_details['bt'], 'regular_male_fi')
        return

    def test_setMatricNumber(self):
        utils = getUtility(IStudentsUtils)
        self.student.matric_number = None
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(msg, 'Wrong state.')
        IWorkflowState(self.student).setState('school fee paid')
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(msg, 'Matriculation number cannot be set.')
        self.assertEqual(mnumber, None)
        self.student['studycourse'].entry_mode = 'nd_ft'
        self.student['studycourse'].entry_session = 2013
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(self.student.matric_number, 'ND/13/dep1/FT/001')
        self.assertEqual(
            self.app['faculties']['fac1']['dep1'].next_matric_dict,
            {2013: 2})
        # setting a new matric number in 2014, extends next_matric_dict
        self.student['studycourse'].entry_session = 2014
        self.student.matric_number = None
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(
            self.app['faculties']['fac1']['dep1'].next_matric_dict,
            {2013: 2, 2014: 2})
        # setting a new matric number in 2014 again, increases the counter
        self.student.matric_number = None
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(
            self.app['faculties']['fac1']['dep1'].next_matric_dict,
            {2013: 2, 2014: 3})
        # matric number must not exist
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(msg, 'Matriculation number already set.')
        # certificate must be set.
        self.student.matric_number = None
        self.student['studycourse'].certificate = None
        msg, mnumber = utils.setMatricNumber(self.student)
        self.assertEqual(msg, 'No certificate assigned.')
        return